<?php

namespace Drupal\twig_placeholders\Service;

/**
 * Generates simple Lorem Ipsum text.
 */
class LoremIpsumGenerator {

  /**
   * Predefined list of Latin words.
   *
   * @var string[]
   */
  protected array $words = [
    'lorem', 'ipsum', 'dolor', 'sit', 'amet', 'consectetur', 'adipiscing', 'ac',
    'proin', 'accumsan', 'sapien', 'nec', 'massa', 'volutpat', 'venenatis', 'a',
    'purus', 'lacinia', 'pretium', 'quis', 'congue', 'praesent', 'risus', 'dui',
    'sagittis', 'laoreet', 'auctor', 'mauris', 'non', 'velit', 'eros', 'dictum',
    'elit', 'curabitur', 'duis', 'hendrerit', 'libero', 'eleifend', 'facilisis',
    'nunc', 'ornare', 'odio', 'orci', 'gravida', 'imperdiet', 'nullam', 'netus',
    'sed', 'eu', 'molestie', 'lacus', 'quisque', 'porttitor', 'diam', 'blandit',
    'mollis', 'tempus', 'at', 'magna', 'vestibulum', 'turpis', 'ligula', 'cras',
    'tincidunt', 'id', 'condimentum', 'enim', 'sodales', 'in', 'hac', 'aliquet',
    'interdum', 'tellus', 'malesuada', 'rhoncus', 'luctus', 'ante', 'fringilla',
    'cursus', 'aliquam', 'quam', 'dapibus', 'nisl', 'feugiat', 'egestas', 'per',
    'class', 'aptent', 'taciti', 'sociosqu', 'ad', 'litora', 'torquent', 'nibh',
    'et', 'nam', 'suspendisse', 'potenti', 'vivamus', 'sem', 'porta', 'viverra',
    'leo', 'eget', 'semper', 'mattis', 'tortor', 'scelerisque', 'nulla', 'nisi',
    'conubia', 'nostra', 'inceptos', 'himenaeos', 'phasellus', 'lobortis', 'ut',
    'pulvinar', 'vitae', 'urna', 'iaculis', 'metus', 'commodo', 'erat', 'fames',
    'pharetra', 'vulputate', 'maecenas', 'est', 'morbi', 'pellentesque', 'arcu',
    'sollicitudin', 'rutrum', 'bibendum', 'vel', 'lectus', 'tempor', 'dictumst',
    'donec', 'justo', 'vehicula', 'ultricies', 'varius', 'fermentum', 'integer',
    'primis', 'ultrices', 'posuere', 'cubilia', 'etiam', 'convallis', 'euismod',
    'suscipit', 'habitant', 'faucibus', 'consequat', 'aenean', 'neque', 'fusce',
    'habitasse', 'felis', 'augue', 'elementum', 'placerat', 'senectus', 'curae',
    'tristique', 'ullamcorper', 'mi', 'platea',
  ];

  /**
   * Generates Lorem Ipsum text.
   *
   * @param int $word_count
   *   The number of words to generate.
   *
   * @return string
   *   Generated Lorem Ipsum text.
   */
  public function generate(int $word_count = 20): string {
    $words = [];

    for ($i = 0; $i < $word_count; $i++) {
      $words[] = $this->words[array_rand($this->words)];

      // Add a full stop every 8-12 words.
      if ($i > 0 && $i % rand(8, 12) === 0) {
        $words[$i] .= '.';
      }
    }

    // Capitalise the first word.
    $words[0] = ucfirst($words[0]);

    // Ensure the last word ends with a full stop.
    if (substr(end($words), -1) !== '.') {
      $words[array_key_last($words)] .= '.';
    }

    return implode(' ', $words);
  }

}
