<?php

namespace Drupal\Tests\twig_placeholders\Unit\Service;

use Drupal\twig_placeholders\Service\LoremIpsumGenerator;
use PHPUnit\Framework\TestCase;

/**
 * Unit tests for the Lorem Ipsum Generator service.
 *
 * @group twig_placeholders
 */
class LoremIpsumGeneratorTest extends TestCase {

  /**
   * The Lorem Ipsum generator.
   *
   * @var \Drupal\twig_placeholders\Service\LoremIpsumGenerator
   */
  protected LoremIpsumGenerator $loremIpsumGenerator;

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();
    $this->loremIpsumGenerator = new LoremIpsumGenerator();
  }

  /**
   * Test the generation of Lorem Ipsum text with default word count.
   */
  public function testGenerateDefaultWordCount(): void {
    $result = $this->loremIpsumGenerator->generate();

    // Ensure at least 20 words.
    $this->assertGreaterThanOrEqual(20, str_word_count($result));
  }

  /**
   * Test the generation of Lorem Ipsum text with a custom word count.
   */
  public function testGenerateCustomWordCount(): void {
    $result = $this->loremIpsumGenerator->generate(50);

    // Ensure at least 50 words.
    $this->assertGreaterThanOrEqual(50, str_word_count($result));
  }

  /**
   * Test the capitalization of the first word.
   */
  public function testFirstWordCapitalization(): void {
    $result = $this->loremIpsumGenerator->generate();
    $words = explode(' ', $result);
    $this->assertEquals(ucfirst($words[0]), $words[0]);
  }

  /**
   * Test that the last word ends with a full stop.
   */
  public function testEndsWithFullStop(): void {
    $result = $this->loremIpsumGenerator->generate();
    $this->assertStringEndsWith('.', $result);
  }

}
