<?php

namespace Drupal\Tests\twig_placeholders\Unit\Twig;

use Drupal\twig_placeholders\Twig\LoremIpsumExtension;
use Drupal\twig_placeholders\Service\LoremIpsumGenerator;
use PHPUnit\Framework\MockObject\MockObject;
use PHPUnit\Framework\TestCase;
use Twig\Environment;
use Twig\Loader\ArrayLoader;

/**
 * @coversDefaultClass \Drupal\twig_placeholders\Twig\LoremIpsumExtension
 *
 * @group twig_placeholders
 */
class LoremIpsumExtensionTest extends TestCase {

  /**
   * The Twig environment.
   *
   * @var \Twig\Environment
   */
  protected Environment $twig;

  /**
   * The mocked Lorem Ipsum generator.
   *
   * @var \Drupal\twig_placeholders\Service\LoremIpsumGenerator&\PHPUnit\Framework\MockObject\MockObject
   */
  protected LoremIpsumGenerator&MockObject $mockGenerator;

  /**
   * Set up the test environment.
   */
  protected function setUp(): void {
    // Mock the LoremIpsumGenerator service.
    $this->mockGenerator = $this->createMock(LoremIpsumGenerator::class);

    // Create a new instance of the LoremIpsumExtension class with the mocked
    // service.
    $extension = new LoremIpsumExtension($this->mockGenerator);

    // Set up Twig with the extension.
    $loader = new ArrayLoader([
      // This is a dummy template; we will use the tp_lorem_ipsum function in
      // it.
      'test_template' => '{{ tp_lorem_ipsum() }}',
    ]);

    $this->twig = new Environment($loader);
    $this->twig->addExtension($extension);
  }

  /**
   * Tests the tp_lorem_ipsum function.
   */
  public function testLoremIpsumFunction(): void {
    // Define the expected result.
    $expectedOutput = 'Lorem ipsum dolor sit amet.';

    // Set up the mock to return the expected output when the generate method is
    // called.
    $this->mockGenerator
      ->expects($this->once())
      ->method('generate')
      ->willReturn($expectedOutput);

    // Render the template using the tp_lorem_ipsum function.
    $actualOutput = $this->twig->render('test_template');

    // Assert that the generated output matches the expected output.
    $this->assertEquals($expectedOutput, $actualOutput);
  }

}
